<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Indicatorstijl</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Moderne modus</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficiënte modus</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klassieke modus</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Gecentreerde modus</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Bovenaan</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Altijd tonen</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Altijd verbergen</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Slim verbergen</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Dockinstellingen</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>